django\_sorcery.management package
==================================

.. automodule:: django_sorcery.management
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    django_sorcery.management.commands

Submodules
----------

.. toctree::

   django_sorcery.management.alembic
   django_sorcery.management.base

